@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-`pyAgrum <http://agrum.org>`_ a scientific C++ and Python library dedicated to Bayesian Networks and other Probabilistic Graphical Models. Based on the C++ `aGrUM <https://agrum.lip6.fr>`_ library, it provides a high-level interface to the C++ part of aGrUM allowing to create, manage and perform efficient computations with Bayesian Networks.
+`pyAgrum <http://agrum.org>`_ a scientific C++ and Python library dedicated to Bayesian Networks and other Probabilistic Graphical Models. Based on the C++ `aGrUM <https://agrum.lip6.fr>`_ library, it provides a high-level interface to the C++ part of aGrUM allowing to create, manage and perform efficient computations with Bayesian networks and others probabilsitic graphical models (Markov networks, influence diagrams and LIMIDs, dynamic BN, probabilistic relational models).
 
 The module is generated using the `SWIG <https://www.swig.org>`_ interface generator. Custom-written code was added to make the interface more friendly.
 
@@ -27,7 +27,7 @@ pyAgrum includes :
 #*   Free Software Foundation, Inc.,                                       *
 #*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-__version__ = '0.18.2'
+__version__ = '0.19.2'
 __license__ = __doc__
 __project_url__ = 'http://agrum.org'
 
@@ -56,7 +56,7 @@ from .pyAgrum import PythonApproximationListener, PythonBNListener, PythonLoadLi
 from .pyAgrum import BNGenerator, IDGenerator, JunctionTreeGenerator
 from .pyAgrum import BNLearner
 from .pyAgrum import BNDatabaseGenerator
-from .pyAgrum import InfluenceDiagram, InfluenceDiagramInference
+from .pyAgrum import InfluenceDiagram, ShaferShenoyLIMIDInference
 from .pyAgrum import CredalNet, CNMonteCarloSampling, CNLoopyPropagation
 from .pyAgrum import PRMexplorer
 
@@ -78,7 +78,7 @@ __all__=[
   'about',
   'availableBNExts', 'loadBN', 'saveBN',
   'availableMNExts', 'loadMN', 'saveMN',
-  'loadID',
+  'availableIDExts', 'loadID', 'saveID',
   'getPosterior',
   'statsObj',
 
@@ -95,7 +95,7 @@ __all__=[
   'BNGenerator','IDGenerator','JunctionTreeGenerator',
   'BNLearner',
   'BNDatabaseGenerator',
-  'InfluenceDiagram','InfluenceDiagramInference',
+  'InfluenceDiagram','ShaferShenoyLIMIDInference',
   'CredalNet','CNMonteCarloSampling','CNLoopyPropagation',
   'PRMexplorer',
 
@@ -133,7 +133,7 @@ def about():
   about() for pyAgrum
 
   """
-  print("pyAgrum version {0}".format('0.18.2'))
+  print("pyAgrum version {0}".format('0.19.2'))
   print("(c) 2015-2020 Pierre-Henri Wuillemin, Christophe Gonzales, Lionel Torti")
   print("""
     This is free software; see the source code for copying conditions.
@@ -246,6 +246,13 @@ def availableMNExts():
   """
   return "uai"
 
+def availableIDExts():
+  """ Give the list of all formats known by pyAgrum to save a influence diagram.
+
+  :return: a string which lists all suffixes for supported ID file formats.
+  """
+  return "bifxml"
+
 def loadMN(filename, listeners=None, verbose=False):
   """load a MN from a file with optional listeners and arguments
 
@@ -306,16 +313,17 @@ def saveMN(mn, filename):
   :param filename(str): the name of the output file
   """
   extension = filename.split('.')[-1].upper()
-  if extension == "UAI":
-    mn.saveUAI(filename)
-  else:
+  if extension not in availableMNExts():
     raise InvalidArgument("[pyAgrum] extension "+filename.split('.')
                           [-1]+" unknown. Please use among "+availableMNExts())
 
+  # for now, just one format
+  mn.saveUAI(filename)
+
 
 def loadID(filename):
   """
-  read a gum.InfluenceDiagram from a bifxml file
+  read a gum.InfluenceDiagram from a ID file
 
   :param filename: the name of the input file
   :return: an InfluenceDiagram
@@ -327,6 +335,7 @@ def loadID(filename):
                           " unknown. Please use bifxml.")
 
   diag = InfluenceDiagram()
+  # for now, just one format
   res = diag.loadBIFXML(filename)
 
   if not res:
@@ -335,22 +344,27 @@ def loadID(filename):
   diag.setProperty("name", filename)
   return diag
 
+
+def saveID(infdiag, filename):
+  """
+  save an ID into a file using the format corresponding to one of the availableWriteIDExts() suffixes.
+
+  :param ID(gum.InfluenceDiagram): the ID to save
+  :param filename(str): the name of the output file
+  """
+  extension = filename.split('.')[-1].upper()
+  if extension not in availableIDExts():
+    raise InvalidArgument("[pyAgrum] extension " + filename.split('.')
+    [-1] + " unknown. Please use among " + availableIDExts())
+
+  # for now, just one format
+  infdiag.saveBIFXML(filename)
+
 def fastBN(structure, domain_size=2):
   """
 Create a Bayesian network with a dot-like syntax which specifies:
-    - the structure 'a->b->c;b->d<-e;'.
-    - the type of the variables with different syntax:
-
-      - by default, a variable is a gum.RangeVariable using the default domain size (second argument)
-      - with `'a[10]'`, the variable is a gum.RangeVariable using 10 as domain size (from 0 to 9)
-      - with 'a[3,7]', the variable is a gum.RangeVariable using a domainSize from 3 to 7
-      - with 'a[1,3.14,5,6.2]', the variable is a gum.DiscretizedVariable using the given ticks (at least 3 values)
-      - with 'a{top|middle|bottom}', the variable is a gum.LabelizedVariable using the given labels.
-
-Note 
-----
-  - If the dot-like string contains such a specification more than once for a variable, the first specification will be used.
-  - the CPTs are randomly generated.
+    - the structure 'a->b->c;b->d<-e;',
+    - the type of the variables with different syntax (cf documentation).
     
 Examples
 --------
@@ -361,7 +375,7 @@ Parameters
 ----------
 structure : str
         the string containing the specification
-domainSize : int
+domain_size : int
         the default domain size for variables
 
 Returns
@@ -373,21 +387,10 @@ pyAgrum.BayesNet
 
 def fastMN(structure, domain_size=2):
   """
-Create a Markov network with a dot-like syntax which specifies:
-    - the structure 'a-b-c;b-d;c-e;'.
-    - the type of the variables with different syntax:
+Create a Markov network with a modified dot-like syntax which specifies:
+    - the structure 'a-b-c;b-d;c-e;' where each chain 'a-b-c' specifies a factor,
+    - the type of the variables with different syntax (cf documentation).
 
-      - by default, a variable is a gum.RangeVariable using the default domain size (second argument)
-      - with `'a[10]'`, the variable is a gum.RangeVariable using 10 as domain size (from 0 to 9)
-      - with 'a[3,7]', the variable is a gum.RangeVariable using a domainSize from 3 to 7
-      - with 'a[1,3.14,5,6.2]', the variable is a gum.DiscretizedVariable using the given ticks (at least 3 values)
-      - with 'a{top|middle|bottom}', the variable is a gum.LabelizedVariable using the given labels.
-
-Note 
-----
-  - If the dot-like string contains such a specification more than once for a variable, the first specification will be used.
-  - the potentials are randomly generated.
-    
 Examples
 --------
 >>> import pyAgrum as gum
@@ -395,19 +398,50 @@ Examples
 
 Parameters
 ----------
-dotlike : str
+structure : str
         the string containing the specification
-domainSize : int
+domain_size : int
         the default domain size for variables
 
 Returns
 -------
-pyAgrum.MARKOVNet
+pyAgrum.MarkovNet
         the resulting Markov network 
   """
   return MarkovNet.fastPrototype(structure, domain_size)
 
 
+
+def fastID(structure, domain_size=2):
+  """
+Create an Influence Diagram with a modified dot-like syntax which specifies:
+    - the structure 'a->b<-c;b->d;c<-e;',
+    - the type of the variables with different syntax (cf documentation),
+    - a prefix for the type of node (chance/decision/utiliy nodes):
+
+      - ``a`` : a chance node named 'a' (by default)
+      - ``$a`` : a utility node named 'a'
+      - ``*a`` : a decision node named 'a'
+    
+Examples
+--------
+>>> import pyAgrum as gum
+>>> bn=gum.fastID('A->B[1,3]<-*C{yes|No}->$D<-E[1,2.5,3.9]',6)
+
+Parameters
+----------
+structure : str
+        the string containing the specification
+domain_size : int
+        the default domain size for variables
+
+Returns
+-------
+pyAgrum.InfluenceDiagram
+        the resulting Influence Diagram
+  """
+  return InfluenceDiagram.fastPrototype(structure, domain_size)
+
 def getPosterior(model, evs, target):
   """
   Compute the posterior of a single target (variable) in a BN given evidence
@@ -429,7 +463,7 @@ def getPosterior(model, evs, target):
 
   Returns
   -------
-    posterior (gum::Potential)
+    posterior (pyAgrum.Potential or other)
   """
   if isinstance(model,BayesNet):
     inf = VariableElimination(model)
@@ -445,7 +479,7 @@ def getPosterior(model, evs, target):
   return Potential(inf.posterior(target))
 
 
-def generateCSV(bn, name_out, n, visible=False, with_labels=False, random_order=True):
+def generateCSV(bn, name_out, n, show_progress=False, with_labels=False, random_order=True):
   """
   generate a CSV file of samples from a bn.
 
@@ -455,8 +489,8 @@ def generateCSV(bn, name_out, n, visible=False, with_labels=False, random_order=
   :type name_out: string
   :param n: the number of samples
   :type n: int
-  :param visible: if True, show a progress bar
-  :type visible: boolean
+  :param show_progress: if True, show a progress bar
+  :type show_progress: boolean
   :param with_labels: if True, use the labels of the modalities of variables in the csv. If False, use their ids.
   :type with_labels: boolean
   :param random_order: if True, the columns in the csv are randomized sorted
@@ -465,7 +499,7 @@ def generateCSV(bn, name_out, n, visible=False, with_labels=False, random_order=
   """
 
   genere = BNDatabaseGenerator(bn)
-  if visible:
+  if show_progress:
     from pyAgrum.lib._utils.progress_bar import ProgressBar
     prog = ProgressBar(name_out + ' : ', 0, 100, 77, mode='static', char='#')
     prog.display()
@@ -489,7 +523,7 @@ def generateCSV(bn, name_out, n, visible=False, with_labels=False, random_order=
 
   genere.toCSV(name_out, with_labels)
 
-  if visible:
+  if show_progress:
     print("Log2-Likelihood : {}".format(ll))
 
   return ll
